# EIDA Consistency Report: `GEOFON`

- Seed: `193844`
- Time: `2025-09-08T16:52:04.053038+00:00`
- Epochs requested: `20`
- Candidates requested: `20`
- Candidates tested: `None`
- Station queries performed: `None`
- Duration/epoch: `600 s`
- Total checks run: `20`
- Consistent: `20`
- Inconsistent: `0`
- Score: **100.0 %**

## Inconsistency Breakdown
- Availability says YES, Dataselect says NO: `0`
- Availability says NO, Dataselect says YES: `0`

## Dataselect Response Types
- **NoTrace**: `5`
- **SingleTrace**: `15`

---

## Detailed Results
### `4C.PAJ7..SHE`
- Window: `2018-01-25T06:57:16 → 2018-01-25T07:07:16`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `9N.00579..HSF`
- Window: `2018-09-03T01:53:04 → 2018-09-03T02:03:04`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `7G.SP07..HHN`
- Window: `2018-04-11T10:25:30 → 2018-04-11T10:35:30`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `9H.P116..HHE`
- Window: `2017-07-08T07:03:03 → 2017-07-08T07:13:03`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `9C.HR26..HHZ`
- Window: `2011-06-26T04:36:11 → 2011-06-26T04:46:11`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `9H.TR32..HHZ`
- Window: `2013-08-22T15:08:04 → 2013-08-22T15:18:04`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `1D.01620..HSF`
- Window: `2021-07-25T01:15:30 → 2021-07-25T01:25:30`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `5H.COO47..HHN`
- Window: `2015-05-12T19:35:17 → 2015-05-12T19:45:17`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `5L.URE..HHN`
- Window: `2014-09-08T07:53:56 → 2014-09-08T08:03:56`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `XF.R11..HHZ`
- Window: `2023-02-16T19:39:07 → 2023-02-16T19:49:07`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `9J.BR09..EHE`
- Window: `2017-06-02T10:41:16 → 2017-06-02T10:51:16`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `3Q.DB064..EHZ`
- Window: `2021-07-19T22:34:01 → 2021-07-19T22:44:01`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `TQ.TQ05..WRP`
- Window: `2023-06-19T01:38:41 → 2023-06-19T01:48:41`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `GX.CAMPI..HHN`
- Window: `2025-07-24T03:59:01 → 2025-07-24T04:09:01`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `ZE.AM18..HHN`
- Window: `2014-10-22T12:28:18 → 2014-10-22T12:38:18`
- Availability: `False`
- Dataselect: `False`
- Type: `NoTrace`
- Status: `NoData`
- Consistent: `✔️`

### `1D.00207..HSF`
- Window: `2021-08-02T13:53:04 → 2021-08-02T14:03:04`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `XF.254..DHN`
- Window: `2020-07-28T21:35:08 → 2020-07-28T21:45:08`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `XF.212..DHE`
- Window: `2020-07-27T16:32:08 → 2020-07-27T16:42:08`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `XF.M07..HHZ`
- Window: `2023-02-11T20:00:33 → 2023-02-11T20:10:33`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`

### `1C.WAR6..HHN`
- Window: `2016-07-28T10:39:48 → 2016-07-28T10:49:48`
- Availability: `True`
- Dataselect: `True`
- Type: `SingleTrace`
- Status: `OK`
- Consistent: `✔️`
